از روشهای API زیر برای دریافت دادههای مربوط به test caseها، مثل عنوان، فیلدهای test case و history، و همچنین ایجاد، ویرایش یا حذف test caseها استفاده کنید.
get_case #
یک test case موجود را برمیگرداند.
GET index.php?/api/v2/get_case/{case_id}
Parameterها #
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| case_id | integer | true | ID test case |
نمونه request:
# Get the test case with an ID of 42
GET index.php?/api/v2/get_case/42
محتوای پاسخ #
نمونه پاسخ:
{
"id": 1,
"title": "Print document history and attributes",
"section_id": 1,
"template_id": 1,
"type_id": 2,
"priority_id": 2,
"milestone_id": null,
"refs": null,
"created_by": 1,
"created_on": 1646317844,
"updated_by": 1,
"updated_on": 1646317844,
"estimate": null,
"estimate_forecast": "8m 40s",
"suite_id": 1,
"display_order": 1,
"is_deleted": 0,
"custom_automation_type": 0,
"custom_preconds": null,
"custom_steps": null,
"custom_expected": null,
"custom_steps_separated": null,
"custom_mission": null,
"custom_goals": null,
"labels": [
{
"id": 1,
"title": "label1",
"created_by:"2",
"created_on: "timestamp",
},
{
"id": 2,
"title": "label2",
"created_by":"2",
"created_on": "timestamp",
}
]
}
فیلدهای سیستمی زیر همیشه در پاسخ برگردانده میشوند:
| نام | نوع | توضیح |
|---|---|---|
| created_by | integer | ID کاربری که test case را ایجاد کرده است |
| created_on | timestamp | تاریخ/زمان ایجاد test case (بهصورت UNIX timestamp) |
| estimate | timespan | مقدار estimate، مثلا “30s” یا “1m 45s” |
| estimate_forecast | timespan | مقدار estimate_forecast، مثلا “30s” یا “1m 45s” |
| id | integer | ID یکتای test case |
| milestone_id | integer | ID milestone مرتبط با test case |
| priority_id | integer | ID priority مرتبط با test case |
| refs | string | فهرستی از referenceها/requirementهای مرتبط با test case که با کاما جدا شدهاند |
| section_id | integer | ID sectionی که test case به آن تعلق دارد |
| suite_id | integer | ID test suiteی که test case به آن تعلق دارد |
| template_id | integer | ID template (چیدمان فیلد) که test case از آن استفاده میکند —به TestRail ۵.۲ یا نسخههای بعدی نیاز دارد |
| title | string | عنوان test case |
| type_id | integer | ID نوع test case مرتبط با این test case |
| updated_by | integer | ID کاربری که آخرین بار test case را بهروزرسانی کرده است |
| updated_on | timestamp | تاریخ/زمان آخرین بهروزرسانی test case (بهصورت UNIX timestamp) |
فیلدهای سفارشی نیز در پاسخ برگردانده میشوند و از نام سیستمی خود با پیشوند «custom_» بهعنوان شناسه فیلد استفاده میکنند. برای مشاهده add_case فهرست کامل نوعهای فیلد سفارشی موجود را ببینید.
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test case در پاسخ برگردانده میشود) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
get_cases #
فهرست test caseهای یک project یا test suite مشخص را برمیگرداند (اگر چند test suite برای project فعال باشد).
GET index.php?/api/v2/get_cases/{project_id}&suite_id={suite_id}
Parameterها #
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| project_id | integer | true | ID project |
| suite_id | integer | توضیح را ببینید | ID test suite (اگر project در حالت single suite کار میکند، اختیاری است) |
| created_after | timestamp | false | فقط test caseهایی را برگردان که بعد از این تاریخ ایجاد شدهاند (بهصورت UNIX timestamp) |
| created_before | timestamp | false | فقط test caseهایی را برگردان که قبل از این تاریخ ایجاد شدهاند (بهصورت UNIX timestamp) |
| created_by | integer (list) | false | فهرستی از ایجادکنندگان (user IDها)، جداشده با کاما، برای فیلتر کردن |
| filter | string | false | فقط caseهایی را برگردان که string فیلتر در عنوان test case آنها وجود دارد |
| limit | integer | false | تعداد test caseهایی که پاسخ باید برگرداند (اندازه پیشفرض پاسخ ۲۵۰ است) —به TestRail ۶.۷ یا نسخههای بعدی نیاز دارد |
| milestone_id | integer (list) | false | فهرستی از milestone IDها، جداشده با کاما، برای فیلتر کردن (اگر فیلد milestone برای project غیرفعال باشد، در دسترس نیست) |
| offset | integer | false | از کجا شمارش test caseها شروع شود (offset) —به TestRail ۶.۷ یا نسخههای بعدی نیاز دارد |
| priority_id | integer (list) | false | فهرستی از priority IDها، جداشده با کاما، برای فیلتر کردن |
| refs | string | false | یک reference ID تنها (مثلا TR-۱، ۴۲۹۱ و غیره) —به TestRail ۶.۵.۲ یا نسخههای بعدی نیاز دارد |
| section_id | integer | false | ID یک section مربوط به test case |
| template_id | integer (list) | false | فهرستی از template IDها، جداشده با کاما، برای فیلتر کردن —به TestRail ۵.۲ یا نسخههای بعدی نیاز دارد |
| type_id | integer (list) | false | فهرستی از case type IDها، جداشده با کاما، برای فیلتر کردن |
| updated_after | timestamp | false | فقط test caseهایی را برگردان که بعد از این تاریخ بهروزرسانی شدهاند (بهصورت UNIX timestamp) |
| updated_before | timestamp | false | فقط test caseهایی را برگردان که قبل از این تاریخ بهروزرسانی شدهاند (بهصورت UNIX timestamp) |
| updated_by | integer | false | فهرستی از user IDهایی که test caseها را بهروزرسانی کردهاند، جداشده با کاما، برای فیلتر کردن |
| label_id | integer (list) | false | فهرستی از label IDها، جداشده با کاما، برای فیلتر کردن |
نمونه requestها:
# Get all the test cases that are in project 34 (project ID of 34), suite with ID of 2 and priority 3 or 4
GET index.php?/api/v2/get_cases/34&suite_id=2&priority_id=3,4
# Get 10 test cases from project 34
GET index.php?/api/v2/get_cases/34&limit=10
# Only returning test cases from project 34 starting the offset number
GET index.php?/api/v2/get_cases/34&offset=5
# Filter cases in project 34 with a filter string of "login"
GET index.php?/api/v2/get_cases/34&filter=login
# Combined usage
GET index.php?/api/v2/get_cases/34&offset=:5&limit=:10&filter=:login
محتوای پاسخ #
پاسخ شامل آرایهای از test caseها است. هر test case در آرایه objectهای «cases» همان قالب پاسخ get_case را دارد.
{
"offset": 0,
"limit": 250,
"size": 250,
"_links": {
"next": "/api/v2/get_cases/1&limit=250&offset=250",
"prev": null
},
"cases": [
{
"id": 1,
"title": "..",
},
{
"id": 2,
"title": "..",
}
]
}
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test caseها در پاسخ برگردانده میشوند) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
get_history_for_case #
#
این endpoint به TestRail ۶.۵.۴ یا نسخههای بعدی نیاز دارد.
history ویرایش یک test case_id را برمیگرداند.
GET index.php?/api/v2/get_history_for_case/{case_id}
Parameterها #
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| case_id | integer | true | ID test case |
| limit | integer | false | تعداد تغییرات test case که پاسخ باید برگرداند (اندازه پیشفرض پاسخ ۲۵۰ است) — به TestRail ۶.۷ یا نسخههای بعدی نیاز دارد |
| offset | integer | false | از کجا شمارش تغییرات test case شروع شود (offset) — به TestRail ۶.۷ یا نسخههای بعدی نیاز دارد |
فیلدهای سیستمی زیر همیشه در پاسخ برگردانده میشوند:
| نام | نوع | توضیح |
|---|---|---|
| id | integer | ID تغییر test case |
| created_on | timestamp | UNIX timestamp زمانی که تغییر انجام شده است |
| type_id | integer | نوع تغییر. این مقدار معمولا ۶ است و نشاندهنده «update» است. (مقدارهای type_id در آرایه «changes» در ادامه توضیح داده شدهاند) |
| user_id | integer | ID کاربری که تغییر را انجام داده است |
| changes | array | آرایهای از جزئیات تغییرات انجامشده روی test caseها |
فیلدهای زیر میتوانند در changes array قرار بگیرند:
| نام | نوع | توضیح |
|---|---|---|
| type_id | integer | نوع فیلد بهروزرسانیشده 1 = string 2 = integer 3 = boolean 4 = date 5 = timespan 6 = text 7 = URL 8 = steps |
| old_text | text | مقدار متنی قبلی فیلد بهروزرسانیشده (برای فیلدهای text استفاده میشود) |
| new_text | text | مقدار متنی جدید فیلد بهروزرسانیشده (برای فیلدهای text استفاده میشود) |
| label | string | label فیلد همانطور که در UI دیده میشود |
| options | array | آرایهای از optionهای configurationشده در فیلد، مثل required، default value و موارد مشابه. |
| field | string | نام سیستمی فیلد بهروزرسانیشده |
| old_value | varies | مقدار قبلی فیلد بهروزرسانیشده. این مورد برای هر فیلد غیرمتنی، از جمله فیلد steps جداگانه، استفاده میشود. بسته به نوع فیلد، مقدار میتواند text یا integer باشد |
| new_value | varies | مقدار جدید فیلد بهروزرسانیشده. این مورد برای هر فیلد غیرمتنی، از جمله فیلد steps جداگانه، استفاده میشود. بسته به نوع فیلد، مقدار میتواند text یا integer باشد |
محتوای پاسخ #
پاسخ شامل آرایهای از تغییرات test case است. هر ورودی در آرایه یک رکورد تغییر است:
[
{
"offset": 0,
"limit": 250,
"size": 1,
"_links": {
"next": null,
"prev": null
},
"history": [
{
"id": 3382,
"type_id": 6,
"created_on": 1597927176,
"user_id": 1,
"changes": [
{
"type_id": 1,
"old_text": "Original Section",
"new_text": "Updated Section",
"field": "section_id",
"old_value": 3573,
"new_value": 3574
},
]
},
{
"id": 3389,
"type_id": 6,
"created_on": 1597932715,
"user_id": 1,
"changes": [
{
"type_id": 1,
"field": "refs",
"old_value": null,
"new_value": "1"
},
]
},
]
}
]
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (history test case در پاسخ برگردانده میشود) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
add_case #
یک test case جدید ایجاد میکند.
POST index.php?/api/v2/add_case/{section_id}
Parameterها #
فیلدهای POST زیر پشتیبانی میشوند (فیلدهای سیستمی):
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| section_id | integer | true | ID sectionی که test case باید به آن اضافه شود |
| title | string | true | عنوان test case |
| template_id | integer | false | ID template (چیدمان فیلد) —به TestRail ۵.۲ یا نسخههای بعدی نیاز دارد |
| type_id | integer | false | ID نوع test case |
| priority_id | integer | false | ID priority test case |
| estimate | timespan | false | مقدار estimate، مثلا “30s” یا “1m 45s” |
| milestone_id | integer | false | ID milestoneی که باید به test case لینک شود |
| refs | string | false | فهرستی از referenceها/requirementها، جداشده با کاما |
| labels | array از مقدارهای mixed (integer یا string) | false | ID یک label، عنوان یک label، یا هر دو، در قالب array. |
parameterهای فیلد سفارشی نیز پشتیبانی میشوند و باید با نام سیستمی خود و پیشوند «custom_» ارسال شوند، مثلا:
{
"custom_preconds": "These are the preconditions for a test case"
}
نوعهای فیلد سفارشی زیر پشتیبانی میشوند:
| نام | نوع | توضیح |
|---|---|---|
| Checkbox | boolean | برای حالت انتخابشده true و در غیر این صورت false |
| Date | string | تاریخ با همان قالبی که برای TestRail و کاربر API تنظیم شده است (مثلا “۰۷/۰۸/۲۰۱۳”) |
| Dropdown | integer | ID یکی از مقدارهای Dropdown، مطابق configuration فیلد |
| Integer | integer | یک integer معتبر |
| Milestone | integer | ID یک milestone برای فیلد سفارشی |
| Multi-select | array | آرایهای از IDها، مطابق configuration فیلد |
| Steps | array | آرایهای از objectها که steps را مشخص میکند. نمونه زیر را هم ببینید |
| String | string | یک string معتبر با حداکثر طول ۲۵۰ کاراکتر |
| Text | string | یک string بدون محدودیت طول |
| URL | string | stringی که با ساختار URL مطابقت داشته باشد |
| User | integer | ID یک کاربر برای فیلد سفارشی |
نمونه request #
همچنین نمونه زیر نشان میدهد چگونه steps را با فیلد سفارشی structured steps و یک test step مشترک ارسال کنید:
{
"title": "This is a test case",
"type_id": 1,
"priority_id": 3,
"estimate": "3m",
"refs": "RF-1, RF-2",
"custom_steps_separated": [
{
"content": "Step 1",
"expected": "Expected Result 1"
},
{
"content": "Step 2",
"expected": "Expected Result 2"
},
{
"shared_step_id": 3
},
"labels": [
‘label1, ‘label5’,7,9,10,’label8’
]
]
}
محتوای پاسخ #
در صورت موفقیت، این method test case جدید را با همان قالب پاسخ get_case برمیگرداند. نمونه پاسخ:
{
"id": 1,
"title": "Print document history and attributes",
"section_id": 1,
"template_id": 1,
"type_id": 2,
"priority_id": 2,
"milestone_id": null,
"refs": null,
"created_by": 1,
"created_on": 1646317844,
}
فیلدهای سیستمی زیر همیشه در پاسخ برگردانده میشوند:
| نام | نوع | توضیح |
|---|---|---|
| created_by | integer | ID کاربری که test case را ایجاد کرده است |
| created_on | timestamp | تاریخ/زمان ایجاد test case (بهصورت UNIX timestamp) |
| estimate | timespan | مقدار estimate، مثلا “30s” یا “1m 45s” |
| estimate_forecast | timespan | مقدار estimate_forecast، مثلا “30s” یا “1m 45s” |
| id | integer | ID یکتای test case |
| milestone_id | integer | ID milestone مرتبط با test case |
| priority_id | integer | ID priority مرتبط با test case |
| refs | string | فهرستی از referenceها/requirementهای مرتبط با test case که با کاما جدا شدهاند |
| section_id | integer | ID sectionی که test case به آن تعلق دارد |
| suite_id | integer | ID test suiteی که test case به آن تعلق دارد |
| template_id | integer | ID template (چیدمان فیلد) که test case از آن استفاده میکند —به TestRail ۵.۲ یا نسخههای بعدی نیاز دارد |
| title | string | عنوان test case |
| type_id | integer | ID نوع test case مرتبط با این test case |
| updated_by | integer | ID کاربری که آخرین بار test case را بهروزرسانی کرده است |
| updated_on | timestamp | تاریخ/زمان آخرین بهروزرسانی test case (بهصورت UNIX timestamp) |
فیلدهای سفارشی نیز در پاسخ برگردانده میشوند و از نام سیستمی خود با پیشوند «custom_» بهعنوان شناسه فیلد استفاده میکنند. برای مشاهده add_case فهرست کامل نوعهای فیلد سفارشی موجود را ببینید.
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test case در پاسخ ایجاد میشود) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
copy_cases_to_section #
فهرست caseها را در test suite یا section دیگری کپی میکند.
POST index.php?/api/v2/copy_cases_to_section/{section_id}
Parameterها #
فیلدهای POST زیر پشتیبانی میشوند (فیلدهای سیستمی):
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| section_id | integer | true | ID sectionی که test case باید در آن کپی شود |
| case_ids | array of integers | false | فهرستی از case IDها، جداشده با کاما |
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test caseها در پاسخ کپی میشوند) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
update_case #
یک test case موجود را بهروزرسانی میکند (بهروزرسانی جزئی پشتیبانی میشود؛ یعنی میتوانید فقط فیلدهای مشخصی را ارسال و بهروزرسانی کنید).
POST index.php?/api/v2/update_case/{case_id}
Parameterها #
فیلدهای POST زیر پشتیبانی میشوند (فیلدهای سیستمی):
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| case_id | integer | true | ID test case |
| section_id | integer | false | ID section جدید برای test case |
| title | string | false | عنوان test case |
| template_id | integer | false | ID template (چیدمان فیلد) —به TestRail ۵.۲ یا نسخههای بعدی نیاز دارد |
| type_id | integer | false | ID نوع test case |
| priority_id | integer | false | ID priority test case |
| estimate | timespan | false | مقدار estimate، مثلا “30s” یا “1m 45s” |
| milestone_id | integer | false | ID milestoneی که باید به test case لینک شود |
| refs | string | false | فهرستی از referenceها/requirementها، جداشده با کاما |
| labels | array از مقدارهای mixed (integer یا string) | false | ID یک label، عنوان یک label، یا هر دو، در قالب array. |
این method همان فیلدهای POST add_case را پشتیبانی میکند. بهروزرسانی section_id یک case به TestRail ۶.۵.۲ یا نسخههای بعدی نیاز دارد.
نمونه request #
همچنین نمونه زیر نشان میدهد چگونه فیلدهای priority و estimate را برای یک test case بهروزرسانی کنید:
{
"priority_id": 1,
"estimate": "5m"
}
محتوای پاسخ #
در صورت موفقیت، این method test case بهروزرسانیشده را با همان قالب پاسخ get_case برمیگرداند.
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test case در پاسخ بهروزرسانی میشود) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
update_cases #
چند test case را با مقدارهای یکسان بهروزرسانی میکند؛ مثلا تنظیم مجموعهای از test caseها روی priority «High». این method از بهروزرسانی چند test case با مقدارهای متفاوت برای هر test case پشتیبانی نمیکند.
POST index.php?/api/v2/update_cases/{suite_id}
Parameterها #
فیلدهای POST زیر پشتیبانی میشوند (فیلدهای سیستمی):
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| case_ids | array of integers | true | ID caseهایی که باید بهروزرسانی شوند |
| suite_id | integer | توضیح را ببینید | ID test suite (اگر project در حالت single suite کار میکند، اختیاری است) |
| section_id | integer | false | ID section جدید برای test case |
| title | string | false | عنوان test case |
| template_id | integer | false | ID template (چیدمان فیلد) —به TestRail ۵.۲ یا نسخههای بعدی نیاز دارد |
| type_id | integer | false | ID نوع test case |
| priority_id | integer | false | ID priority test case |
| estimate | timespan | false | مقدار estimate، مثلا “30s” یا “1m 45s” |
| milestone_id | integer | false | ID milestoneی که باید به test case لینک شود |
| refs | string | false | فهرستی از referenceها/requirementها، جداشده با کاما |
| labels | array از مقدارهای mixed (integer یا string) | false | ID یک label، عنوان یک label، یا هر دو، در قالب array. |
این method همان فیلدهای POST add_case را پشتیبانی میکند. بهروزرسانی section_id یک case به TestRail ۶.۵.۲ یا نسخههای بعدی نیاز دارد.
نمونه request #
همچنین نمونه زیر نشان میدهد چگونه فیلدهای priority و estimate را برای یک test case بهروزرسانی کنید. فیلد case_ids یک فیلد الزامی است و test caseهایی را مشخص میکند که باید بهروزرسانی شوند:
{
"case_ids": [1, 2, 3],
"priority_id": 1,
"estimate": "5m"
}
محتوای پاسخ #
در صورت موفقیت، این method test caseهای بهروزرسانیشده را با همان قالب پاسخ get_case برمیگرداند.
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test caseها در پاسخ برگردانده میشوند) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
move_cases_to_section #
caseها را به test suite یا section دیگری منتقل میکند.
POST index.php?/api/v2/move_cases_to_section/{section_id}
Parameterها #
فیلدهای POST زیر پشتیبانی میشوند (فیلدهای سیستمی):
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| section_id | integer | true | ID sectionی که case به آن منتقل میشود |
| suite_id | integer | true | ID test suiteی که case به آن منتقل میشود |
| case_ids | array of integers | true | فهرستی از case IDها، جداشده با کاما |
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test caseها در پاسخ بهروزرسانی میشوند) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
delete_case #
#
حذف test case قابل بازگشت نیست و تمام test resultهای آن را در test runهای فعال نیز برای همیشه حذف میکند (یعنی test runهایی که هنوز بسته یا archive نشدهاند).
یک test case موجود را حذف میکند.
POST index.php?/api/v2/delete_case/{case_id}
Parameterها #
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| case_id | integer | true | ID test case |
| soft | integer | false | soft=۱ اطلاعاتی درباره دادههایی که حذف خواهند شد برمیگرداند، اما حذف را انجام نمیدهد |
Parameter soft #
#
اگر parameter soft را وارد نکنید یا soft=۰ ارسال کنید، test case حذف میشود.
اگر soft=1 باشد، دادههایی درباره تعداد testهای تحتتأثیر برمیگرداند.
قرار دادن soft=1 باعث حذف واقعی entity نمیشود.
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test case در پاسخ حذف میشود) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |
delete_cases #
#
حذف test case قابل بازگشت نیست و تمام test resultهای آن را در test runهای فعال نیز برای همیشه حذف میکند (یعنی test runهایی که هنوز بسته یا archive نشدهاند).
چند test case را از یک project یا test suite حذف میکند.
POST index.php?/api/v2/delete_cases/{suite_id}&soft=1
Parameterها #
| نام | نوع | الزامی | توضیح |
|---|---|---|---|
| case_ids | array of integers | true | آرایهای از IDهای test caseهایی که میخواهید حذف کنید |
| project_id | integer | true | ID project |
| suite_id | integer | توضیح را ببینید | ID test suite (فقط وقتی لازم است که project در حالت multi-suite باشد) |
| soft | integer | false | soft=۱ اطلاعاتی درباره دادههایی که حذف خواهند شد برمیگرداند، اما حذف را انجام نمیدهد |
نمونه request #
همچنین نمونه زیر را ببینید که case IDهای project انتخابشده را نشان میدهد.
{
"case_ids": [1, 2, 3]
}
کدهای پاسخ #
| Status Code | توضیح |
|---|---|
| 200 | موفقیت (test caseها در پاسخ حذف میشوند) |
| 400 | test case نامعتبر یا ناشناخته |
| 403 | به project دسترسی ندارید |
| 429 | فقط برای TestRail Cloud—درخواستهای بیش از حد (ببینید API rate limit) |

